Quick Help (quickhelp)

# Orange Canvas Core 0.0.8 documentation

## Quick Help (quickhelp)

# Quick Help (`quickhelp`)

class `orangecanvas.gui.quickhelp.` `QuickHelp`(*args, **kwargs)

  Bases: `PyQt5.QtWidgets.QTextBrowser`

  `textChanged`

    Emitted when the shown text changes.

  `showHelp`(text, timeout=0)

    Show help for timeout milliseconds. if timeout is 0 then show the text until it is cleared with clearHelp or showHelp is called with an empty string.

  `clearHelp`()

    Clear help text previously set with showHelp.

  `showPermanentHelp`(text)

    Set permanent help text. The text may be temporarily overridden by showHelp but will be shown again when that is cleared.

  `currentText`()

    Return the current shown text.